@@ -1337,9 +1337,8 @@ int main(int argc, char ** argv)
     while ((opt=getopt(argc,argv,"d:f:o:V")) != -1) {
         switch (opt) {
             case 'd':
-                if ((((templ=strtol(optarg,NULL,0)) == 0) &&
-                        (errno == EINVAL || errno == ERANGE )) ||
-                        (templ < 0) || (templ > 9)) {
+                errno=0;
+                if (((templ=strtol(optarg,NULL,0)) <= 0) || templ > 9) {
                     logerr(errno,"Bad debug level %s: Must be 1-9",optarg);
                     err++;
                 } else
@@ -1522,7 +1521,7 @@ int main(int argc, char ** argv)
     /* One more spin through the list now we've initialised the name to id
      * mapping so we can update references to "name" with an id
      */
-    for (ifptr=engine->next;ifptr;ifptr=ifptr->next) {
+    for (ifptr=lists.initialized;ifptr;ifptr=ifptr->next) {
         if (ifptr->ofilter)
             if (name2id(ifptr->ofilter))
                 logterm(errno,"Name to interface translation failed");
